.. _refman:

================
Reference Manual
================

Module, class, and function reference

HydraTK
=======

.. toctree::
   :maxdepth: 1

   refman/hydra/core
   refman/hydra/lib
   
Extensions   
==========

.. toctree::
   :maxdepth: 1

   refman/ext/benchmark   